# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['meltano',
 'meltano.api',
 'meltano.api.controllers',
 'meltano.api.events',
 'meltano.api.executor',
 'meltano.api.models',
 'meltano.api.security',
 'meltano.api.workers',
 'meltano.cli',
 'meltano.core',
 'meltano.core.behavior',
 'meltano.core.block',
 'meltano.core.bundle',
 'meltano.core.container',
 'meltano.core.hub',
 'meltano.core.job',
 'meltano.core.legacy_tracking',
 'meltano.core.logging',
 'meltano.core.plugin',
 'meltano.core.plugin.dbt',
 'meltano.core.plugin.singer',
 'meltano.core.runner',
 'meltano.core.tracking',
 'meltano.core.utils',
 'meltano.migrations',
 'meltano.migrations.versions',
 'meltano.oauth']

package_data = \
{'': ['*'],
 'meltano.api': ['static/*',
                 'static/css/*',
                 'static/js/*',
                 'static/logos/*',
                 'templates/*',
                 'templates/email/pipeline_manual_run/*',
                 'templates/security/*',
                 'templates/security/email/*'],
 'meltano.core.tracking': ['iglu-client-embedded/schemas/com.meltano/block_event/jsonschema/*',
                           'iglu-client-embedded/schemas/com.meltano/cli_context/jsonschema/*',
                           'iglu-client-embedded/schemas/com.meltano/cli_event/jsonschema/*',
                           'iglu-client-embedded/schemas/com.meltano/environment_context/jsonschema/*',
                           'iglu-client-embedded/schemas/com.meltano/plugins_context/jsonschema/*',
                           'iglu-client-embedded/schemas/com.meltano/project_context/jsonschema/*',
                           'iglu-client-embedded/schemas/com.meltano/telemetry_state_change_event/jsonschema/*'],
 'meltano.oauth': ['templates/*']}

install_requires = \
['MarkupSafe<2.1.0',
 'aiodocker>=0.21.0,<0.22.0',
 'aiohttp>=3.4.4,<4.0.0',
 'alembic>=1.5.0,<2.0.0',
 'async_generator>=1.10,<2.0',
 'atomicwrites>=1.2.1,<2.0.0',
 'authlib>=0.10,<0.11',
 'bcrypt>=3.2.0,<4.0.0',
 'cached-property>=1,<2',
 'click-default-group>=1.2.1,<2.0.0',
 'click>=7.0,<8.0',
 'email-validator>=1.1.2,<2.0.0',
 'fasteners>=0.15.0,<0.16.0',
 'flask-cors>=3.0.7,<4.0.0',
 'flask-executor>=0.9.2,<0.10.0',
 'flask-restful>=0.3.7,<0.4.0',
 'flask-sqlalchemy>=2.4.4,<3.0.0',
 'flask>=1,<2',
 'flatten-dict>=0,<1',
 'gunicorn>=19.9.0,<20.0.0',
 'ipython>=7.5.0,<8.0.0',
 'jsonschema>=3.0.0,<4.0.0',
 'markdown>=3.0.1,<4.0.0',
 'meltano-flask-security>=0.1.0,<0.2.0',
 'networkx>=2.2,<3.0',
 'psutil>=5.6.3,<6.0.0',
 'psycopg2-binary>=2.8.5,<3.0.0',
 'pyhocon>=0.3.51,<0.4.0',
 'pyhumps>=3.0.0,<4.0.0',
 'pypika>=0.25.1,<0.26.0',
 'python-dotenv>=0.14.0,<0.15.0',
 'python-gitlab>=1.8.0,<2.0.0',
 'pyyaml>=5.3.1,<6.0.0',
 'requests>=2.23.0,<3.0.0',
 'simplejson>=3.16.0,<4.0.0',
 'smtpapi>=0.4.1,<0.5.0',
 'snowflake-sqlalchemy>=1.2.3,<2.0.0',
 'snowplow-tracker>=0.10.0,<0.11.0',
 'sqlalchemy>=1.3.19,<2.0.0',
 'sqlparse>=0.3.0,<0.4.0',
 'structlog>=21.2.0,<22.0.0',
 'tzlocal>=4.2.0,<5.0.0',
 'uvicorn[standard]>=0.17.6,<0.18.0',
 'watchdog>=0.9.0,<0.10.0',
 'werkzeug>=1,<2']

entry_points = \
{'console_scripts': ['meltano = meltano.cli:main']}

setup_kwargs = {
    'name': 'meltano',
    'version': '2.0.1',
    'description': 'Meltano: Your DataOps Platform Infrastructure',
    'long_description': '![](https://lh4.googleusercontent.com/WHoN-WpacMaVicq-jRuIvCQjCIdPZwYOwBgd38k9JjMpX1Z7THUqowY-oRsTzGUbAvb8F4tcb9BJYyfX9MeA2ECirsWZ7XBHteDZ_y59REMwHjq1AX05U2k8H6mdI4G_olF27gadCfp1Wx7cVQ)\n=========================================================================================================================================================================================\n\nMeltano\n-------\n\nWelcome to your Open Source DataOps Infrastructure to manage and centralize all the data tools in your stack and turn them into your ideal end-to-end data platform. With Meltano, you\'ll be able to collaboratively build and improve your data platform like a software project; spinning up a service or tool (Airflow, dbt, Great Expectations, Snowflake, etc) and easily configuring, deploying and managing it through a single control plane.\n\n![](https://lh3.googleusercontent.com/1uzR_ETj6Kj1eleSjkbCpi5ZfqxFDm4hd6jzZ7JVxi2ajI9gPyjEyg6bspvha7O8dYpO3s9Y-CN6hfwiY8rvsmh9rsZ4oACh-FhvwfRBJS8oCsE76Twkf_UCHWLSmxEdvSaYyDTIqKVrdpsvsg)\n\nIntegrations\n------------\n\n[MeltanoHub](https://hub.meltano.com/) is the single source of truth to find any Meltano plugins as well as [Singer](https://singer.io/) taps and targets. Users are also able to add more plugins to the Hub and have them immediately discoverable and usable within Meltano. The Hub is lovingly curated by Meltano and the wider Meltano community.\n\nInstallation\n------------\n\nIf you\'re ready to build your ideal data platform and start running data workflows across multiple tools, start by following the [Installation guide](https://docs.meltano.com/guide/installation) to have Meltano up and running in your device.\n\nDocumentation\n-------------\n\nCheck out the ["Getting Started" guide](https://docs.meltano.com/getting-started) or find the full documentation at [https://docs.meltano.com](https://docs.meltano.com/).\n\nContributing\n------------\n\nMeltano is a truly open-source project, built for and by its community. We happily welcome and encourage your contributions. Start by browsing through our [issue tracker](https://github.com/meltano/meltano/issues?q=is%3Aopen+is%3Aissue) to add your ideas to the roadmap. If you\'re still unsure on what to contribute at the moment, you can always check out the list of open issues labeled as "[Accepting Merge Requests](https://github.com/meltano/meltano/issues?q=is%3Aopen+is%3Aissue+label%3A%22accepting+merge+requests%22)".\n\nFor more information on how to contribute to Meltano, refer to our [contribution guidelines](https://docs.meltano.com/contribute/).\n\nCommunity\n---------\n\nWe host weekly online events where you can engage with us directly. Check out more information in our [Community](https://meltano.com/community/) page.\n\nIf you have any questions, want sneak peeks of features or would just like to say hello and network, join our community of over +2,500 data professionals!\n\n👋 [Join us on Slack!](https://meltano.com/slack)\n\nResponsible Disclosure Policy\n-----------------------------\n\nPlease refer to the [responsible disclosure policy](https://docs.meltano.com/the-project/responsible-disclosure) on our website.\n\nLicense\n-------\n\nThis code is distributed under the MIT license, see the [LICENSE](https://github.com/meltano/meltano/blob/main/LICENSE) file.\n',
    'author': 'Meltano',
    'author_email': 'hello@meltano.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/meltano/meltano',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<3.10',
}


setup(**setup_kwargs)
